@@ -13,40 +13,40 @@ package Data::SUID;
 
 =head1 NAME
 
-Data::SUID - Generates thread-safe sequential unique ids 
+Data::SUID - Generates thread-safe sequential unique ids
 
 =head1 SYNOPSIS
 
     use Data::SUID 'suid';              # Or use ':all' tag
     use Data::Dumper;
-    
+
     $Data::Dumper::Indent = 0;
     $Data::Dumper::Terse  = 1;
-    
+
     my $suid = suid();                  # Old school, or ...
     my $suid = Data::SUID->new();       # Do it OOP style
-    
+
     print $suid->hex                    # 55de233819d51b1a8a67e0ac
     print $suid->dec                    # 26574773684474770905501261996
     print $suid->uuencode               # ,5=XC.!G5&QJ*9^"L
     print $suid->binary                 # 12 bytes of unreadable gibberish
     print $suid                         # 55de233819d51b1a8a67e0ac
-    
+
 
     # Use the hex, dec, uuencode and binary methods as fire-and-forget
-    # constructors, if you prefer:    
-    
+    # constructors, if you prefer:
+
     my $suid_hex = suid->hex;           # If you just want the goodies
-    
+
 =head1 DESCRIPTION
 
-Use this package to generate thread-safe 12-byte sequential unique ids 
+Use this package to generate thread-safe 12-byte sequential unique ids
 modeled upon the MongoDB BSON ObjectId. Unlike traditional GUIDs, these
-are somewhat more index-friendly and reasonably suited for use as 
+are somewhat more index-friendly and reasonably suited for use as
 primary keys within database tables. They are guaranteed to have a high
 level of uniqueness, given that they contain a timestamp, a host identifier
 and an incremented sequence number.
-  
+
 =cut
 
 use strict;
@@ -61,12 +61,12 @@ use Readonly;
 use namespace::clean;
 use overload '""' => 'hex';
 
-our $VERSION = '1.000003';
+our $VERSION = '1.000004';
 $VERSION = eval($VERSION);
 
 our @ISA         = qw(Exporter);
 our @EXPORT_OK   = qw(suid);
-our %EXPORT_TAGS = ( all => \@EXPORT_OK );
+our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
 
 =head1 METHODS
 
@@ -82,13 +82,14 @@ Generates a new SUID object.
 
 =cut
 
+
 sub new
 {
     my ($class) = @_;
     $class = $class || __PACKAGE__;
     my $time = time();
     my $host = &_machine_ident;
-    Readonly my $id => sprintf( '%08x%s%04x%s', $time, $host, $$, &_count ); # SUID value cannot be modified.
+    Readonly my $id => sprintf( '%08x%s%04x%s', $time, $host, $$, &_count );
     return bless( \$id, $class );
 }
 
@@ -99,11 +100,11 @@ sub new
 Returns the SUID value as a 24-character hexadecimal string.
 
 The SUID object's stringification operation has been overloaded to give this value, too.
-
 =back
 
 =cut
 
+
 sub hex
 {
     my ($self) = @_;
@@ -121,6 +122,7 @@ Returns the SUID value as a big integer.
 
 =cut
 
+
 sub dec
 {
     my ($self) = @_;
@@ -138,11 +140,12 @@ Returns the SUID value as a UUENCODED string.
 
 =cut
 
+
 sub uuencode
 {
     my ($self) = @_;
     $self = &new unless ref($self);
-    return pack('u', pack('H*', $$self));
+    return pack( 'u', pack( 'H*', $$self ) );
 }
 
 =over 2
@@ -155,12 +158,13 @@ Returns the SUID value as 12 bytes of binary data.
 
 =cut
 
+
 sub binary
 {
     use bytes;
     my ($self) = @_;
     $self = &new unless ref($self);
-    return pack('H*', $$self);
+    return pack( 'H*', $$self );
 }
 
 =head1 EXPORTED FUNCTIONS
@@ -177,6 +181,7 @@ Generates a new SUID object.
 
 =cut
 
+
 sub suid
 {
     return __PACKAGE__->new(@_);
@@ -189,9 +194,11 @@ sub suid
     lock @ident;
     lock $ident;
 
-    @ident = +( map 0 + $_, Net::Address::Ethernet::get_address() )[ 3, 4, 5 ];    # Don't want the 24-bit OUID!
+    # Don't want the 24-bit OUID!
+    @ident = +( map 0+ $_, Net::Address::Ethernet::get_address() )[ 3, 4, 5 ];
     $ident = sprintf( '%02x%02x%02x', @ident );
 
+
     sub _machine_ident
     {
         return wantarray ? @ident : $ident;
@@ -204,6 +211,7 @@ sub suid
     my $count_format   = '%0' . int( $count_width / 4 ) . 'x';
     my $count : shared = undef;
 
+
     sub _reset_count
     {
         my ( $class, $value ) = @_;
@@ -211,20 +219,21 @@ sub suid
         lock $count;
         $count = undef;
 
-        if ( defined $value )
-        {
-            $count = $count_mask & ( 0 + abs($value) );
+        if ( defined $value ) {
+            $count = $count_mask & ( 0+ abs($value) );
         }
 
-        unless ( defined $count )
-        {
-            my $random = Crypt::Random::makerandom( Strength => 1, Uniform => 1, Size => $count_width );
-            $count = "$random";    # Can't share $random between threads, so coerce as string and assign to count
+        unless ( defined $count ) {
+            my $random
+              = Crypt::Random::makerandom( Strength => 1, Uniform => 1, Size => $count_width );
+
+            # Can't share $random between threads, so coerce as string and
+            # assign to count
+            $count = "$random";
         }
 
         return $class;
     }
-
     sub _count
     {
         &_reset_count unless defined $count;
